# update-service
This is the API documentation for the Mbed deployment service, which is part of the update service.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 3
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import update_service 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import update_service
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import update_service
from update_service.rest import ApiException
from pprint import pprint

# Configure API key authorization: Bearer
update_service.configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# update_service.configuration.api_key_prefix['Authorization'] = 'Bearer'
# create an instance of the API class
api_instance = update_service.DefaultApi()
datafile = '/path/to/file.txt' # file | The firmware image file to upload
name = 'name_example' # str | The name of the firmware image
description = 'description_example' # str | The description of the firmware image (optional)

try:
    # Create an image
    api_response = api_instance.firmware_image_create(datafile, name, description=description)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DefaultApi->firmware_image_create: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.us-east-1.mbedcloud.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**firmware_image_create**](docs/DefaultApi.md#firmware_image_create) | **POST** /v3/firmware-images/ | Create an image
*DefaultApi* | [**firmware_image_destroy**](docs/DefaultApi.md#firmware_image_destroy) | **DELETE** /v3/firmware-images/{image_id}/ | Delete an image
*DefaultApi* | [**firmware_image_list**](docs/DefaultApi.md#firmware_image_list) | **GET** /v3/firmware-images/ | List all images
*DefaultApi* | [**firmware_image_retrieve**](docs/DefaultApi.md#firmware_image_retrieve) | **GET** /v3/firmware-images/{image_id}/ | Get an image
*DefaultApi* | [**firmware_manifest_create**](docs/DefaultApi.md#firmware_manifest_create) | **POST** /v3/firmware-manifests/ | Create a manifest
*DefaultApi* | [**firmware_manifest_destroy**](docs/DefaultApi.md#firmware_manifest_destroy) | **DELETE** /v3/firmware-manifests/{manifest_id}/ | Delete a manifest
*DefaultApi* | [**firmware_manifest_list**](docs/DefaultApi.md#firmware_manifest_list) | **GET** /v3/firmware-manifests/ | List manifests
*DefaultApi* | [**firmware_manifest_retrieve**](docs/DefaultApi.md#firmware_manifest_retrieve) | **GET** /v3/firmware-manifests/{manifest_id}/ | Get a manifest
*DefaultApi* | [**update_campaign_create**](docs/DefaultApi.md#update_campaign_create) | **POST** /v3/update-campaigns/ | Create a campaign
*DefaultApi* | [**update_campaign_destroy**](docs/DefaultApi.md#update_campaign_destroy) | **DELETE** /v3/update-campaigns/{campaign_id}/ | Delete a campaign
*DefaultApi* | [**update_campaign_list**](docs/DefaultApi.md#update_campaign_list) | **GET** /v3/update-campaigns/ | List all campaigns
*DefaultApi* | [**update_campaign_metadata_list**](docs/DefaultApi.md#update_campaign_metadata_list) | **GET** /v3/update-campaigns/{campaign_id}/campaign-device-metadata/ | List all campaign device metadata
*DefaultApi* | [**update_campaign_metadata_retrieve**](docs/DefaultApi.md#update_campaign_metadata_retrieve) | **GET** /v3/update-campaigns/{campaign_id}/campaign-device-metadata/{campaign_device_metadata_id}/ | Get a campaign device metadata
*DefaultApi* | [**update_campaign_metadata_stop**](docs/DefaultApi.md#update_campaign_metadata_stop) | **POST** /v3/update-campaigns/{campaign_id}/stop | Stop a running campaign
*DefaultApi* | [**update_campaign_retrieve**](docs/DefaultApi.md#update_campaign_retrieve) | **GET** /v3/update-campaigns/{campaign_id}/ | Get a campaign.
*DefaultApi* | [**update_campaign_update**](docs/DefaultApi.md#update_campaign_update) | **PUT** /v3/update-campaigns/{campaign_id}/ | Modify a campaign


## Documentation For Models

 - [CampaignDeviceMetadata](docs/CampaignDeviceMetadata.md)
 - [CampaignDeviceMetadataPage](docs/CampaignDeviceMetadataPage.md)
 - [FirmwareImage](docs/FirmwareImage.md)
 - [FirmwareImageEqNeqFilter](docs/FirmwareImageEqNeqFilter.md)
 - [FirmwareImageGteLteFilter](docs/FirmwareImageGteLteFilter.md)
 - [FirmwareImageInNinFilter](docs/FirmwareImageInNinFilter.md)
 - [FirmwareImagePage](docs/FirmwareImagePage.md)
 - [FirmwareManifest](docs/FirmwareManifest.md)
 - [FirmwareManifestEqNeqFilter](docs/FirmwareManifestEqNeqFilter.md)
 - [FirmwareManifestGteLteFilter](docs/FirmwareManifestGteLteFilter.md)
 - [FirmwareManifestInNinFilter](docs/FirmwareManifestInNinFilter.md)
 - [FirmwareManifestPage](docs/FirmwareManifestPage.md)
 - [UpdateCampaign](docs/UpdateCampaign.md)
 - [UpdateCampaignEqNeqFilter](docs/UpdateCampaignEqNeqFilter.md)
 - [UpdateCampaignGteLteFilter](docs/UpdateCampaignGteLteFilter.md)
 - [UpdateCampaignInNinFilter](docs/UpdateCampaignInNinFilter.md)
 - [UpdateCampaignPage](docs/UpdateCampaignPage.md)
 - [UpdateCampaignPatchRequest](docs/UpdateCampaignPatchRequest.md)
 - [UpdateCampaignPostRequest](docs/UpdateCampaignPostRequest.md)
 - [UpdateCampaignPutRequest](docs/UpdateCampaignPutRequest.md)


## Documentation For Authorization


## Bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author



